import numpy as np
from numpy.fft import rfft, rfftfreq
import matplotlib.pyplot as plt
from cmath import exp, pi

def dft(t,y,freq):
    nt = len(t)
    nf = len(freq)
    c = np.zeros(nf,complex)
    for k in range(nf):
        f = freq[k]
        for i in range(nt):
            c[k] += y[i]*exp(-2j*pi*f*t[i])
    return 2.*abs(c)/nt

npts = 1000
twopi = 2.* pi

A1  = 1.5 ;  P1 = 10.
A2  = 1.  ;  P2 =  3.

t = np.linspace(0.,100.,npts)
y = A1*np.sin((twopi/P1)*t) + A2*np.sin((twopi/P2)*t)

frac_points = 0.2 # fraction of points to select

r = np.random.rand(y.shape[0])
t_subset = t[r >= (1.0 - frac_points)]
y_subset = y[r >= (1.0 - frac_points)]

nfreq = 1000
freq_dft = np.linspace(0.,1.,nfreq)

amp_dft = dft(t_subset, y_subset, freq_dft)

amp_fft  = np.abs(rfft(y)) * 2 / npts
freq_fft = rfftfreq(npts,t[1]-t[0])

fig = plt.figure()
ax = plt.subplot(311)                  # time series
plt.plot(t_subset,y_subset,'bo',ms=3)
plt.plot(t,y,'r',alpha=0.2)

ax = plt.subplot(312)                  # Discrete Fourier Transform
plt.plot(freq_dft, amp_dft)

ax = plt.subplot(313)                  # FFT
plt.plot(freq_fft, amp_fft)
plt.xlim([0,1])

plt.show()
