import sys
import matplotlib.pyplot as plt
from matplotlib.patches import Rectangle
import numpy as np

status = 0  # plot label sizes, colors, etc.
xsize=14
ysize=10
dpi = 300
labelsize = 18
ticksize = 16
lcolor = '#0000ff'
lwidth = 1.0
fcolor = '#ffff00'

plt.rc('text', usetex=True)  # use LaTeX codes for labels
plt.rc('font',**{'family':'sans-serif','sans-serif':['sans-serif']})
plt.params = {#'backend': 'png',
    'axes.linewidth': 2.0,
    'axes.labelsize': labelsize,
    'axes.font': 'sans-serif',
    'axes.fontweight' : 'bold',
    'text.fontsize': 12,
    'legend.fontsize': 12,
    'xtick.labelsize': ticksize,
    'ytick.labelsize': ticksize}
plt.rcParams.update(plt.params)

infile1 = 'V344Lyr_demo.dat'
plotfile = 'inset+label.pdf'
x1, y1 = np.loadtxt(infile1,unpack=True,usecols=(0,1))

fig = plt.figure(figsize=[xsize,ysize])
ax = plt.axes([0.16,0.2,0.75,0.7])

# first panel
plt.plot(x1,y1,'k,')
xrange = max(x1) - min(x1)
yrange = max(y1) - min(y1)
minx = min(x1)-0.05*xrange
maxx = max(x1)+0.05*xrange
miny = min(y1)-0.05*yrange
maxy = max(y1)+0.05*yrange
plt.axis([minx,maxx,miny,maxy])
plt.xlabel('Time (BJD - 2455000)',labelpad=10)
plt.ylabel(r'SAP Flux ($\rm e^-\ s^{-1}$)')

# Plot Label 'V344 Lyr' at coordinates 0.15, 0.83
plt.text(0.15, 0.83,'V344 Lyr', horizontalalignment='center',
     verticalalignment='center',fontsize=30,
     transform = ax.transAxes)

# Inset
ax.add_patch(Rectangle((279.9,9800),.4,200,alpha=0.3))
plt.plot([279.3,279.9],[6430,9800],'b',alpha=0.3)
plt.plot([280.97,280.3],[6430,9800],'b',alpha=0.3)

ax1 = plt.axes([0.45,0.31,0.15,0.2])
plt.axis([279.9,280.3,10000,15000])
plt.plot(x1,y1,'k,')
plt.xticks([280,280.2],('280','280.2'))
plt.yticks([10000,14000])

plt.savefig(plotfile,dpi=dpi)

plt.show()
